@@ -11,7 +11,7 @@ import tomlkit
 import tomlkit.exceptions
 
 from relationalai.clients.hash_util import hash_string
-from relationalai.tools.constants import FIELD_PLACEHOLDER, SNOWFLAKE_AUTHS
+from relationalai.tools.constants import FIELD_PLACEHOLDER, SNOWFLAKE_AUTHS, SNOWFLAKE_PROFILE_DEFAULTS
 from relationalai.util.constants import DEFAULT_PROFILE_NAME, TOP_LEVEL_PROFILE_NAME
 
 PUBLIC_CONFIG_KEYS = [
@@ -58,7 +58,7 @@ azure_default_props = {
 
 def default_engine_size(platform: Literal["snowflake"]|Literal["azure"], internal=False):
     if platform == "snowflake" and not internal:
-        return "HIGHMEM_X64_S"
+        return SNOWFLAKE_PROFILE_DEFAULTS["engine_size"]["value"]
     else:
         return "S"
 
@@ -564,7 +564,7 @@ class Config():
         else:
             self.set("platform", "snowflake")
             self.fill_in_with_snowflake_defaults()
-    
+
     def is_internal_account(self):
         acct = self.get("account", "")
         acct = acct if isinstance(acct, str) else ""
@@ -572,10 +572,10 @@ class Config():
 
     def get_default_engine_size(self):
         config_size = self.get("engine_size", None)
-        if config_size is not None:
-            return config_size
-        else:
+        if config_size is None:
             return default_engine_size("snowflake", internal=self.is_internal_account())
+        else:
+            return config_size
 
     def get_default_auto_suspend_mins(self):
         auto_suspend_mins = self.get("auto_suspend_mins", None)
