@@ -5,7 +5,7 @@ Builder API for RelationalAI.
 from relationalai.early_access.builder.builder import (
     Model, Concept, Relationship, RelationshipReading, Expression, Fragment, Error,
     String, Integer, Float, Decimal, Decimal64, Decimal128, Bool, Date, DateTime,
-    RawSource,
+    RawSource, Hash,
     select, where, require, define, distinct, union, data,
     rank, asc, desc,
     count, sum, min, max, avg, per,
@@ -15,7 +15,7 @@ from relationalai.early_access.builder.builder import (
 __all__ = [
     "Model", "Concept", "Relationship", "RelationshipReading", "Expression", "Fragment", "Error",
     "String", "Integer", "Float", "Decimal", "Decimal64", "Decimal128", "Bool", "Date", "DateTime",
-    "RawSource",
+    "RawSource", "Hash",
     "select", "where", "require", "define", "distinct", "union", "data",
     "rank", "asc", "desc",
     "count", "sum", "min", "max", "avg", "per",
