@@ -20,7 +20,7 @@ def range(*args: Union[b.Producer, int]) -> b.Expression:
     # unlike Python, Rel's range is 1..stop inclusive, so we need to subtract 1 from stop
     return _make_expr("range", start, stop-1, step, b.Integer.ref("res"))
 
-def hash(*args: Any, type=b.Integer) -> b.Expression:
+def hash(*args: Any, type=b.Hash) -> b.Expression:
     if len(args) == 0:
         raise ValueError("hash expects at least one argument")
     return _make_expr("hash", b.TupleArg(args), type.ref("res"))
