@@ -10,19 +10,20 @@ def _make_expr(op: str, *args: Any) -> b.Expression:
 # Coerce a number to Decimal64.
 def decimal64(value: b.Producer|int|float|PyDecimal) -> b.Expression:
     if isinstance(value, int):
-        return _make_expr("int_to_decimal64", value, b.Decimal64.ref("res"))
+        value = PyDecimal(str(value))
     if isinstance(value, float):
-        return _make_expr("float_to_decimal64", value, b.Decimal64.ref("res"))
-    return _make_expr("decimal64", value, b.Decimal64.ref("res"))
+        value = PyDecimal(str(value))
+    return b.ConceptMember(b.Decimal64, value, {})
 
 # Coerce a number to Decimal128.
 def decimal128(value: b.Producer|int|float|PyDecimal) -> b.Expression:
     if isinstance(value, int):
-        return _make_expr("int_to_decimal128", value, b.Decimal128.ref("res"))
+        value = PyDecimal(str(value))
     if isinstance(value, float):
-        return _make_expr("float_to_decimal128", value, b.Decimal128.ref("res"))
-    return _make_expr("decimal128", value, b.Decimal128.ref("res"))
+        value = PyDecimal(str(value))
+    return b.ConceptMember(b.Decimal128, value, {})
 
+# Default decimal to 128 bits.
 def decimal(value: b.Producer|int|float|PyDecimal) -> b.Expression:
     return decimal128(value)
 
