@@ -30,7 +30,8 @@ class Compiler(c.Compiler):
             Checker(),
             InferTypes(),
             Flatten(handle_outputs=False),
-            rewrite.RecursiveUnion()
+            rewrite.RecursiveUnion(),
+            rewrite.DoubleNegation()
         ]
         if not skip_denormalization:
             # group updates, compute SCCs, use Sequence to denote their order
@@ -451,7 +452,7 @@ class ModelToSQL:
         if not_null_vars:
             wheres.extend(sql.NotNull(var) for var in not_null_vars)
 
-        not_exists, _ = self._generate_select_nots(nots, sql_vars, var_column, len(sql_vars))
+        not_exists, _ = self._generate_select_nots(nots, var_lookups, sql_vars, var_column, len(sql_vars))
         wheres.extend(not_exists)
 
         where = self._process_wheres_clauses(wheres)
@@ -624,7 +625,7 @@ class ModelToSQL:
 
         _, vars = self._generate_select_output(outputs, builtin_vars, sql_vars, var_column, var_lookups, var_to_construct)
 
-        not_exists, _ = self._generate_select_nots(nots, sql_vars, var_column, len(sql_vars))
+        not_exists, _ = self._generate_select_nots(nots, var_lookups, sql_vars, var_column, len(sql_vars))
         wheres.extend(not_exists)
 
         where = self._process_wheres_clauses(wheres)
@@ -657,7 +658,7 @@ class ModelToSQL:
         if not_null_vars:
             wheres.extend(sql.NotNull(var) for var in not_null_vars)
 
-        not_exists, _ = self._generate_select_nots(nots, sql_vars, var_column, len(sql_vars))
+        not_exists, _ = self._generate_select_nots(nots, var_lookups, sql_vars, var_column, len(sql_vars))
         wheres.extend(not_exists)
 
         where = self._process_wheres_clauses(wheres)
@@ -1020,6 +1021,10 @@ class ModelToSQL:
 
                 original = original_raw if original_raw in intermediate_builtin_vars else reference(original_raw)
                 builtin_vars[result] = original
+            elif relation in (builtins.isnan, builtins.isinf):
+                arg_expr = self._var_to_expr(args[0], reference, resolve_builtin_var, var_to_construct)
+                expr = "cast('NaN' AS DOUBLE)" if relation == builtins.isnan else "cast('Infinity' AS DOUBLE)"
+                wheres.append(sql.Terminal(f"{arg_expr} = {expr}"))
             else:
                 # Assuming infix binary or ternary operators here
                 lhs_raw, rhs_raw = args[0], args[1]
@@ -1071,13 +1076,23 @@ class ModelToSQL:
                         expr = f"ln({left})"
                     elif rel_name == builtins.sqrt.name:
                         expr = f"sqrt({left})"
-                    elif rel_name in (builtins.minimum.name, builtins.maximum.name):
+                    elif rel_name in (builtins.minimum.name, builtins.maximum.name, builtins.trunc_div.name,
+                                      builtins.power.name, builtins.mod.name):
                         assert len(args) == 3, f"Expected 3 args for {relation}, got {len(args)}: {args}"
 
                         result_var = args[2]
                         right = self._var_to_expr(rhs_raw, reference, resolve_builtin_var, var_to_construct)
 
-                        expr = f"least({left}, {right})" if rel_name == builtins.minimum.name else f"greatest({left}, {right})"
+                        if rel_name == builtins.minimum.name:
+                            expr = f"least({left}, {right})"
+                        elif rel_name == builtins.maximum.name:
+                            expr = f"greatest({left}, {right})"
+                        elif rel_name == builtins.trunc_div.name:
+                            expr = f"trunc({left} / {right})"
+                        elif rel_name == builtins.power.name:
+                            expr = f"power({left}, {right})"
+                        else:
+                            expr = f"mod({left}, {right})"
                     else:
                         raise Exception(f"Unsupported math builtin relation: {relation}")
                     assert isinstance(result_var, ir.Var), (
@@ -1319,8 +1334,9 @@ class ModelToSQL:
                 vars.append(sql.VarRef(str(value), alias=alias))
         return not_null_vars, vars
 
-    def _generate_select_nots(self, nots: Optional[list[ir.Not]], sql_vars: dict[ir.Lookup, str],
-                              var_column:dict[Tuple[ir.Var, ir.Lookup], ir.Field], index: int) -> tuple[list[sql.NotExists], int]:
+    def _generate_select_nots(self, nots: Optional[list[ir.Not]], var_lookups: dict[ir.Var, OrderedSet[ir.Lookup]],
+                              sql_vars: dict[ir.Lookup, str], var_column:dict[Tuple[ir.Var, ir.Lookup], ir.Field],
+                              index: int) -> tuple[list[sql.NotExists], int]:
         not_exists = []
         if nots:
             for not_expr in nots:
@@ -1355,10 +1371,14 @@ class ModelToSQL:
                 froms, wheres, not_sql_vars, not_var_column, not_var_lookups = self._extract_lookups_metadata(lookups, index)
                 index += len(not_sql_vars)
 
+                all_sql_vars = {**sql_vars, **not_sql_vars}
+                all_var_column = {**var_column, **not_var_column}
+                all_var_lookups = {**var_lookups, **not_var_lookups}
+
                 var_to_construct = {c.id_var: c for c in constructs} if constructs else {}
                 builtin_lookups = OrderedSet.from_iterable(t for t in all_lookups if builtins.is_builtin(t.relation))
-                builtin_vars, builtin_wheres = self._resolve_builtins(builtin_lookups, not_var_lookups, not_var_column,
-                                                                      not_sql_vars, var_to_construct)
+                builtin_vars, builtin_wheres = self._resolve_builtins(builtin_lookups, all_var_lookups, all_var_column,
+                                                                      all_sql_vars, var_to_construct)
                 wheres.extend(builtin_wheres)
 
                 # We need to join the not exists select with the outside select query context
@@ -1383,7 +1403,7 @@ class ModelToSQL:
 
                 wheres.extend(self._generate_where_clauses(not_var_lookups, not_var_column, not_sql_vars, union_lookups))
 
-                inner_not_exists, index = self._generate_select_nots(inner_nots, not_sql_vars, not_var_column, index)
+                inner_not_exists, index = self._generate_select_nots(inner_nots, not_var_lookups, not_sql_vars, not_var_column, index)
                 wheres.extend(inner_not_exists)
 
                 where = self._process_wheres_clauses(wheres)
