@@ -110,36 +110,57 @@ class Weaver:
         self._ctor_binding_to_entity_map[binding] = entity_map
 
     def _lookup_supertype_identifier_role_maps(self, binding: IdentifierConceptBinding):
+        """
+        Build a mapping from each reference scheme of the binding's concept to the corresponding constructing role map.
+        """
         concept = binding.entity_type
-        ref_schemes = self._reasoner.ref_schemes_of(concept)
         ref_scheme_to_role_map = OrderedDict()
-        for ref_scheme in ref_schemes:
+
+        for ref_scheme in self._reasoner.ref_schemes_of(concept):
             constructed_concept = self._reasoner.identifies_concept(ref_scheme)
-            constructor_binding = self._binder.lookup_constructor_binding(concept, binding.column)\
-                if constructed_concept is concept\
+
+            #=
+            # May need to look up the constructor binding for another concept with (.id) in the concept's hierarchy.
+            # E.g., if the concept is a subtype with multiple ref schemes, we need to look up the respective constructor
+            # binding for each supertype with a reference scheme.
+            #=
+            constructor_binding = (
+                self._binder.lookup_constructor_binding(concept, binding.column)
+                if constructed_concept is concept
                 else self._binder.lookup_constructor_binding_by_source(constructed_concept, binding.column.table)
+            )
 
             ctor_role = self._binder.lookup_binding_role(constructor_binding)
-            role = ctor_role.sibling()
-            assert role is not None, "Constructor binding must have a sibling role"
-            role_map = self._lookup_constructing_role_map(constructor_binding, role.player())
+            player = ctor_role.player()
+
+            # If the constructor role is played by a primitive, use its sibling's player
+            if player._is_primitive():
+                sibling = ctor_role.sibling()
+                assert sibling is not None, "Constructor roles must have a sibling role"
+                player = sibling.player()
+
+            role_map = self._lookup_constructing_role_map(constructor_binding, player)
             ref_scheme_to_role_map[ref_scheme] = role_map
         return ref_scheme_to_role_map
 
     def _lookup_constructing_role_map(self, binding: Union[IdentifierConceptBinding, ReferentConceptBinding],
-                                      ctor_concept: qb.Concept):
+                                      concept: qb.Concept):
         if self._binder.is_value_type_binding(binding):
             role_map = self._binding_to_value_map[binding]
         elif isinstance(binding, IdentifierConceptBinding):
-            # TODO: this might need to be recursive for chains that are constructed from entity types
-            ctor_binding = self._binder.lookup_constructor_binding(ctor_concept, binding.column)
+            #=
+            # This call is needed to ensure we look up the ctor binding for the concept, which may not be the same as
+            # the one in the binding. This is because the reference scheme may have an entity type in the constructing
+            # role, hence we need to look up the constructor binding and then the role map for that binding.
+            #=
+            ctor_binding = self._binder.lookup_constructor_binding(concept, binding.column)
             assert isinstance(ctor_binding, IdentifierConceptBinding)
             role_map = self._ctor_binding_to_entity_map[ctor_binding]
         elif isinstance(binding, ReferentConceptBinding):
             # TODO: check why we need `binder.lookup_constructor_binding` above?
             role_map = self._ref_binding_to_entity_map[binding]
         else:
-            raise ValueError(f'Cannot lookup constructing role map for binding {binding} and concept {ctor_concept}')
+            raise ValueError(f'Cannot lookup constructing role map for binding {binding} and concept {concept}')
         return role_map
 
     def _generate_referent_entity_maps(self):
