@@ -15,11 +15,22 @@ from typing import Tuple, cast, Union, Optional
 import re
 
 """ Main access point. Converts the model IR to an LQP transaction. """
-def to_lqp(model: ir.Model, fragment_name: bytes) -> tuple[Optional[tuple], lqp.Transaction]:
+def to_lqp(model: ir.Model, fragment_name: bytes, error_attr_ids: Optional[list]) -> tuple[Optional[tuple], Optional[list], lqp.Transaction]:
     assert_valid_input(model)
     ctx = TranslationCtx(model)
     decls: list[lqp.Declaration] = []
 
+    # Extract new pyrel error attributes, if any.
+    # These can be used in a subsequent query to report errors.
+    # TODO (RAI-40312): Revisit this after reworking compiler/executor interface.
+    new_error_ids = _extract_pyrel_error_ids(ctx, model)
+    if error_attr_ids is not None:
+        # If we have error attributes, we need to add them to the context.
+        # This is used to generate the error attributes in the LQP.
+        for (rel_id, name) in error_attr_ids:
+            ctx.output_ids.append((rel_id, name))
+
+
     # LQP only accepts logical tasks
     # These are asserted at init time
     root = cast(ir.Logical, model.root)
@@ -54,7 +65,7 @@ def to_lqp(model: ir.Model, fragment_name: bytes) -> tuple[Optional[tuple], lqp.
     )
 
     lqp.validate_lqp(txn)
-    return (export_info, txn)
+    return (export_info, new_error_ids, txn)
 
 def _effect_bindings(effect: Union[ir.Output, ir.Update]) -> list[ir.Value]:
     if isinstance(effect, ir.Output):
@@ -610,3 +621,19 @@ def constant_to_lqp_var(
     eq = lqp.Primitive(name="rel_primitive_eq", terms=[var, value_term], meta=None)
 
     return var, typ, eq
+
+def _extract_pyrel_error_ids(ctx: TranslationCtx, model: ir.Model) -> list[Tuple[lqp.RelationId, str]]:
+    effects = collect_by_type(ir.Update, model)
+    pyrel_error_attrs = []
+    # We use a separate counter here to avoid modifying the current model.
+    i = 1
+    for effect in effects:
+        if "pyrel_error_attrs" not in effect.relation.name:
+            continue
+        name = f"pyrel_error_attr_{i}"
+        meta_id = effect.relation.id
+        rel_id = get_relation_id(ctx, name, meta_id)
+        pyrel_error_attrs.append((rel_id, name))
+        i += 1
+
+    return pyrel_error_attrs
