@@ -144,7 +144,9 @@ def format_results(results, result_cols:List[str]|None = None)  -> Tuple[DataFra
                                     row.iloc[1]
                                 )
 
-                elif "/:pyrel_error" in relation_id:
+                elif "/:pyrel_error_attr" in relation_id:
+                    assert len(result_frame.columns) == 3, \
+                        f"Error attribute with {len(result_frame.columns)} cols, expected 3"
                     for _, row in result_frame.iterrows():
                         id = convert_hash_value(row.iloc[0])
                         problems[id]["code"] = "PYREL_ERROR"
