@@ -33,6 +33,8 @@ def meta_type_to_lqp(typ: meta.Type) -> lqp.Type:
                 return mk_type(lqp.TypeName.DATE)
             elif typ == types.DateTime:
                 return mk_type(lqp.TypeName.DATETIME)
+            elif typ == types.Hash:
+                return mk_type(lqp.TypeName.UINT128)
             elif typ == types.RowId:
                 return mk_type(lqp.TypeName.UINT128)
             elif typ == types.Number:
@@ -60,6 +62,8 @@ def type_from_constant(arg) -> lqp.Type:
         name = lqp.TypeName.FLOAT
     elif isinstance(arg, str):
         name = lqp.TypeName.STRING
+    elif isinstance(arg, lqp.Int128):
+        name = lqp.TypeName.INT128
     elif isinstance(arg, lqp.UInt128):
         name = lqp.TypeName.UINT128
     else:
