@@ -8,7 +8,7 @@ from relationalai.early_access.metamodel.compiler import Pass, group_tasks
 from relationalai.early_access.metamodel.util import OrderedSet, ordered_set, NameCache
 from relationalai.early_access.metamodel import dependency
 from relationalai.early_access.metamodel.util import FrozenOrderedSet, filter_by_type
-from relationalai.early_access.metamodel.typer.typer import to_type
+from relationalai.early_access.metamodel.typer.typer import to_type, is_primitive
 
 class Flatten(Pass):
     """
@@ -476,22 +476,19 @@ class Flatten(Pass):
                     body.remove(output)
 
                     is_export = builtins.export_annotation in output.annotations
+
+                    original_cols = OrderedSet()
                     # generate an output for each "column"
                     for idx, alias in enumerate(output.aliases):
+                        original_cols.add(alias[1])
                         # output looks like def output(:cols, :col000, key0, key1, value):
-                        aliases = []
-                        if not is_export:
-                            aliases.append(("cols", f.literal("cols", types.Symbol)))
-                        aliases.append(("col", f.literal(f"col{idx:03}", types.Symbol)))
-                        for key in output.keys:
-                            aliases.append((f"key_{key.name}_{idx}", key))
-                        aliases.append(alias)
-                        body.add(ir.Output(
-                            output.engine,
-                            FrozenOrderedSet.from_iterable(aliases),
-                            output.keys,
-                            output.annotations
-                        ))
+                        self._generate_output_column(body, output, idx, alias, is_export)
+
+                    idx = len(output.aliases)
+                    for key in output.keys:
+                        if key not in original_cols:
+                            self._generate_output_column(body, output, idx, (key.name, key), is_export)
+                            idx += 1
 
             # analyse the resulting logical to be able to pull dependencies
             logical = ir.Logical(task.engine, task.hoisted, tuple(body), task.annotations)
@@ -518,6 +515,30 @@ class Flatten(Pass):
 
             return Flatten.HandleResult(None)
 
+    def _generate_output_column(self, body: OrderedSet[ir.Task], output: ir.Output, idx: int, alias: tuple[str, ir.Value], is_export: bool):
+        if not output.keys:
+            return output
+
+        aliases = [("cols", f.literal("cols", types.Symbol))] if not is_export else []
+        aliases.append(("col", f.literal(f"col{idx:03}", types.Symbol)))
+
+        for k in output.keys:
+            aliases.append((f"key_{k.name}_{idx}", k))
+
+        if is_export and isinstance(alias[1], ir.Var) and not is_primitive(alias[1].type):
+            uuid = f.var(f"{alias[0]}_{idx}_uuid", types.String)
+            body.add(f.lookup(builtins.uuid_to_string, [alias[1], uuid]))
+            aliases.append((uuid.name, uuid))
+        else:
+            aliases.append(alias)
+
+        body.add(ir.Output(
+            output.engine,
+            FrozenOrderedSet.from_iterable(aliases),
+            output.keys,
+            output.annotations
+        ))
+
 
     def remove_subsumptions(self, body:OrderedSet[ir.Task], ctx: Context):
         # remove from the body all the tasks that are subsumed by some other task in the set;
