@@ -49,13 +49,15 @@ CONVERSION_LATTICE:set[tuple[ir.Type, ir.Type]] = {
     (types.Int, types.Decimal64),
     (types.Decimal64, types.Decimal128),
     (types.Decimal128, types.Float),
+    # Int -> Hash (UInt128)
+    (types.Int, types.Hash),
     # transitive closure of the above
     (types.Int, types.Decimal128),
     (types.Decimal64, types.Float),
     (types.Int, types.Float),
 }
 
-PRIMITIVES = [types.Int, types.Float, types.Decimal64, types.Decimal128, types.Bool, types.String, types.Date, types.DateTime]
+PRIMITIVES = [types.Int, types.Float, types.Decimal64, types.Decimal128, types.Bool, types.String, types.Date, types.DateTime, types.Hash]
 
 ENTITY_LIKES = [types.RowId]
 
@@ -131,6 +133,8 @@ def literal_conversion_allowed(actual:ir.Type, expected:ir.Type) -> bool:
         return True
     elif actual in (types.Decimal64, types.Decimal128) and expected in (types.Decimal64, types.Decimal128):
         return True
+    elif actual == types.Int and expected == types.Hash:
+        return True
     return False
 
 def conversion_cost(arg: ir.Value, actual:ir.Type, expected:ir.Type, arg_types:set[ir.Type]) -> float:
@@ -153,6 +157,9 @@ def conversion_cost(arg: ir.Value, actual:ir.Type, expected:ir.Type, arg_types:s
     if not base_actual or not base_expected:
         return float("inf")
 
+    if base_actual == base_expected:
+        return 0
+
     if (base_actual, base_expected) in CONVERSION_LATTICE:
         # The cost for converting from one type to another should be the same regardless of the types involved.
         # Otherwise, we'll introduce spurious conversions of say Int->Decimal64 plus a cheap literal conversion
@@ -1054,6 +1061,7 @@ class Replacer(visitor.Rewriter):
         expected_base = to_base_primitive(expected) or expected
         new_arg = f.var(name, expected_base)
         tasks.append(f.lookup(builtins.cast, (expected_base, arg, new_arg)))
+        self.new_relations.add(builtins.cast)
         return new_arg
 
     @staticmethod
