@@ -15,11 +15,11 @@ from relationalai.clients import result_helpers
 from relationalai.clients.util import IdentityParser
 from relationalai.clients.snowflake import APP_NAME
 from relationalai.early_access.metamodel import ir, executor as e, factory as f
-from relationalai.early_access.metamodel.visitor import collect_by_type
 from relationalai.early_access.rel import Compiler
 from relationalai.clients.config import Config
 from relationalai.tools.constants import USE_DIRECT_ACCESS
 
+
 class RelExecutor(e.Executor):
     """Executes Rel code using the RAI client."""
 
@@ -242,7 +242,8 @@ class RelExecutor(e.Executor):
 
             """)
             task_model = f.compute_model(f.logical([task]))
-            task_code = base + self.compiler.compile(task_model, {"no_declares": True, "wide_outputs": self.wide_outputs})
+            task_code, task_model = self.compiler.compile_inner(task_model, {"no_declares": True, "wide_outputs": self.wide_outputs})
+            task_code = base + task_code
             compile_span["compile_type"] = "query"
             compile_span["rel"] = task_code
 
@@ -254,23 +255,20 @@ class RelExecutor(e.Executor):
         if self.dry_run:
             return DataFrame()
 
-        outputs = collect_by_type(ir.Output, task)
-        cols = None
-        if outputs:
-            cols = [alias for alias, _ in outputs[-1].aliases if alias]
+        cols, extra_cols = self._compute_cols(task, task_model)
 
         if not export_to:
             raw_results = resources.exec_raw(self.database, self.engine, full_code, False, nowait_durable=True)
             df, errs = result_helpers.format_results(raw_results, None, cols)  # Pass None for task parameter
             self.report_errors(errs)
-            return df
+            return self._postprocess_df(self.config, df, extra_cols)
         else:
             assert cols
             # The result cols should be a superset of the actual cols.
             if result_cols is not None:
-                assert all(col in result_cols for col in cols)
+                assert all(col in result_cols or col in extra_cols for col in cols)
             else:
-                result_cols = cols
+                result_cols = [col for col in cols if col not in extra_cols]
             assert result_cols
             raw = self._export(full_code, export_to, cols, result_cols, update)
             errors = []
