@@ -1544,12 +1544,16 @@ class SnowflakeImportMissingException(RAIException):
         super().__init__(self.message, self.name, self.content)
 
     def format_message(self):
-        message = f"The Snowflake object '{self.import_name}' hasn't been imported into RAI. You can create an import for it using"
-        return self.message_for_environment(
-            message,
-            f"rai imports:stream --source {self.import_name} --model {self.model_name}",
-            f"rai.Provider().create_streams(['{self.import_name}'], '{self.model_name}')"
-        )
+        return textwrap.dedent(f"""
+            The Snowflake object '{self.import_name}' hasn't been imported into RAI.
+            To automatically handle imports please verify that `use_graph_index` is not set to `False` in your config.
+
+            You can also create an import for it using:
+
+            [green]rai imports:stream --source {self.import_name} --model {self.model_name}[/green]
+
+            [green]rai.Provider().create_streams(['{self.import_name}'], '{self.model_name}')[/green]
+        """)
 
 
 class SnowflakeChangeTrackingNotEnabledException(RAIException):
